@@ -282,6 +282,28 @@ class MainWindowActions(AttrDict):
             shortcut='Ins',
             statustip='Enter/leave selection mode')
 
+        self.shift_cells_down = Action(self.parent, "Shift selection down",
+                                       self.parent.grid.on_shift_cells_down,
+                                       icon=Icon.shift_down,
+                                       statustip='Shift selection down')
+
+        self.shift_cells_right = Action(self.parent, "Shift selection right",
+                                        self.parent.grid.on_shift_cells_right,
+                                        icon=Icon.shift_right,
+                                        statustip='Shift selection right')
+
+        self.delete_shift_cells_up = Action(
+            self.parent, "Delete and shift cells up",
+            self.parent.grid.on_delete_shift_cells_up,
+            icon=Icon.shift_up,
+            statustip='Delete selection and shift cells below it up')
+
+        self.delete_shift_cells_left = Action(
+            self.parent, "Delete and shift cells left",
+            self.parent.grid.on_delete_shift_cells_left,
+            icon=Icon.shift_left,
+            statustip='Delete selection and shift cells right of it left')
+
         self.insert_rows = Action(self.parent, "Insert rows",
                                   self.parent.grid.on_insert_rows,
                                   icon=Icon.insert_row,
@@ -432,6 +454,12 @@ class MainWindowActions(AttrDict):
                    statustip='Apply format from the clipboard to the selected '
                              'cells')
 
+        self.default_format = \
+            Action(self.parent, "&Default format",
+                   self.parent.grid.on_format_default,
+                   icon=Icon.default_format,
+                   statustip='Reset cell format to system theme default')
+
         self.font = Action(self.parent, "&Font...",
                            self.parent.grid. on_font_dialog,
                            icon=Icon.font_dialog,
