@@ -30,10 +30,11 @@
 
 from argparse import ArgumentParser
 from pathlib import Path
+import logging
 import sys
 
 try:
-    import PyQt5.QtSvg as pyqtsvg
+    import PyQt6.QtSvg as pyqtsvg
 except ImportError:
     pyqtsvg = None
 
@@ -75,7 +76,7 @@ def check_mandatory_dependencies():
             dependency_warning(msg)
     if pyqtsvg is None:
         # Import of mandatory module failed
-        msg = "Required module PyQt5.QtSvg not found."
+        msg = "Required module PyQt6.QtSvg not found."
         dependency_warning(msg)
 
 
@@ -97,5 +98,15 @@ class PyspreadArgumentParser(ArgumentParser):
                           help='start with default settings and save them on '
                                'exit')
 
+        self.add_argument('-d', '--debug',
+                          help="Print debug information",
+                          action="store_const", dest="loglevel",
+                          const=logging.DEBUG, default=logging.WARNING)
+
+        self.add_argument('-v', '--verbose',
+                          help="Print verbose information",
+                          action="store_const", dest="loglevel",
+                          const=logging.INFO)
+
         self.add_argument('file', type=Path, nargs='?', default=None,
                           help='open pyspread file in pys or pysu format')
