@@ -34,12 +34,13 @@ pyspread
 
 """
 
+import logging
 import os
 import sys
 import traceback
 
-from PyQt5.QtCore import Qt
-from PyQt5.QtWidgets import QApplication
+from PyQt6.QtCore import Qt
+from PyQt6.QtWidgets import QApplication
 
 try:
     from pyspread.cli import PyspreadArgumentParser
@@ -53,8 +54,6 @@ except ImportError:
 LICENSE = "GNU GENERAL PUBLIC LICENSE Version 3"
 
 os.environ["QT_AUTO_SCREEN_SCALE_FACTOR"] = "1"
-QApplication.setAttribute(Qt.AA_EnableHighDpiScaling, True)
-QApplication.setAttribute(Qt.AA_UseHighDpiPixmaps, True)
 
 
 def excepthook(exception_type, exception_value, exception_traceback):
@@ -74,13 +73,15 @@ def main():
     parser = PyspreadArgumentParser()
     args, _ = parser.parse_known_args()
 
+    logging.basicConfig(level=args.loglevel)
+
     app = QApplication(sys.argv)
     app.setDesktopFileName("io.gitlab.pyspread.pyspread")
     main_window = MainWindow(args.file, default_settings=args.default_settings)
 
     main_window.show()
 
-    app.exec_()
+    app.exec()
 
     sys.exit()
 
